@@ -7,14 +7,12 @@ from foqus.payments import create_plan_stripe
 from ip2geotools.databases.noncommercial import DbIpCity
 
 if not LOCAL:
-    from keras.utils import multi_gpu_model
+    from tensorflow.keras.utils import multi_gpu_model
 
 from currency_converter import CurrencyConverter
-from keras import models
-from keras import layers
-from keras import optimizers
-from keras.applications.vgg16 import VGG16, preprocess_input
-from keras.preprocessing import image
+from tensorflow.keras import models, layers, optimizers
+from tensorflow.keras.applications.vgg16 import VGG16, preprocess_input
+from tensorflow.keras.preprocessing import image
 from math import ceil
 from multiprocessing.pool import ThreadPool, TimeoutError
 
